# oneNeuron_pypi
oneNeuron_pypi

## How to use this

```python
from oneNeuron.perceptron import Perceptron
## first have X and y and then use below commands
model = Perceptron(eta=eta, epochs=epochs)
model.fit(X, y)
```

# Reference - 
[Official Python docs](https://packaging.python.org/en/latest/tutorials/packaging-projects/)


# Reference - 
[Github docs for Github actions](https://docs.github.com/en/actions/automating-builds-and-tests/building-and-testing-python#publishing-to-package-registries)

# Datasets

x1 | x2 | y 
-|-|-
0|0|0 
0|1|0
1|0|0
1|1|1
